/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: 000-startup.sas                                                                     |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       Common Components                                                                             |
|       Utility Code, Module Code, Lookup tables needed for producing the summary tables              |
|       MSCDM tables: DEMTABLE, ENRTABLE, DIATABLE, DISTABLE, PROCTABLE                               |
|                                                                                                     |
|   Program outputs:                                                                                  |
|      All of the temporary, intermediate, and final outputs to produce the summary tables            |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/*******************************************************************************************/
/***  PLEASE DO NOT CHANGE SETTINGS                                                      ***/
/*******************************************************************************************/

/* System options */
options obs=MAX;
options msglevel=i;
options mprint mprintnest;
options errorcheck=strict errors=0;
options merror serror;
options mrecall;
options dkricond=error dkrocond=error mergenoby=warn;
options dsoptions=nonote2err noquotelenmax;
options reuse=no;
options lrecl=32767;
options fullstimer;
options threads;
options ls=150 nocenter;

/* Testing at large DP shows compression hurts because the package splits large MSCDM tables  */
/* when extracting and SAS frequently compresses smaller datasets when it should not */
/* (i.e. SAS log message says compression increased the size of the dataset) */ 
options compress=NO;

*** Clear out WORK folder at the start of the job;
proc datasets lib=work kill nolist nowarn nodetails;
quit ;

/* Define summary tables version macro variable */
%let PackageName = Summary Tables ;
%let PackageVersion = V2.0 ;
%put *** &=PackageName &=PackageVersion;

/* Define list of CDM tables to use for summary tables creation package */
%global ST_TableList;
%let ST_TableList = %upcase(&DEMTABLE &ENRTABLE &DIATABLE &DISTABLE &PROCTABLE);
%put *** &=ST_TableList;

/* Display DP ETL # and DP Min/Max Dates */
%put *** DP &=ETL ;
%put *** DP_MinDate: %sysfunc(putn(&DP_MinDate, date9.)) ;
%put *** DP_MaxDate: %sysfunc(putn(&DP_MaxDate, date9.)) ;
%put;

/* Define DP start year, DP end year, and DP num years global macro variables */
%global DP_StartYear DP_EndYear DP_NumYears;
%let DP_StartYear = %sysfunc(year(&DP_MinDate)); %let DP_EndYear = %sysfunc(year(&DP_MaxDate));
%let DP_NumYears = %eval((&DP_EndYear.-&DP_StartYear.)+1);
%put *** &=DP_StartYear &=DP_EndYear &=DP_NumYears;
%put;

/* Define DP Start Qtr and DP End Qtr global macro variables */
%global DP_StartQuarter DP_EndQuarter;
%let DP_StartQuarter=%sysfunc(qtr(&DP_MinDate.)); %let DP_EndQuarter=%sysfunc(qtr(&DP_MaxDate.));
%put *** &=DP_StartQuarter &=DP_EndQuarter ;
%put;

/* Define date format to use */
%let DateFMT = mmddyy10.;

/* Include utility macros, formats, and user functions */
%include "&MODULE_CODE.utility_code.sas" /source ;

/* Include code to validate inputs */
%INC_NEXT( code=VALIDATE_INPUTS, log=N )

/* Call macro to determine which has more levels: age-groups or time-periods */
%Age_vs_Period ;

/* Capture overall ST START TIME */
%global st_start_time ;
%TimeStamp(parm=st_start_time);

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^;

* End of 000-startup.sas;
