/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: dx_etl.sas                                                                          |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: September 10, 2015                                                                          |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       PatKey demographic table                                                                      |
|       Macro TableExtract                                                                            |
|   Program outputs:                                                                                  |
|       Multiple tables named DxYYY1, DxYYY2, DxYYY3, etc.                                            |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

%* MOD: 09/24/15 -MR: Tweak HashVarsRead to drop PatID from HashData: HashVarsRead=PatKey Birth_Date Sex ;
%* MOD: 10/08/15 -MR: Add 10/07/15 modifications from RR ;
%*                 - Replace calculated year(Adate) function call with calculated _Year variable ;
%*                 - Replace CovKeyVar with CovKeyVars ;
%* MOD: 10/11/15 -RR: Add filtering of ADate between DP min and max dates ;
%*                  - Add use of ReplaceVarPairs parm for enabling output SORTEDBY option ;
%* MOD: 12/5/15  -RR: Created output file as view;
%* MOD: 12/8/15  -RR: Made call to CovKeyVars=CovKeyDrugAndMed;

*** Create extract of Diagnosis table, with these requirements:
*** 1) DX_CodeType="09" and EncType is one of: AV, ED, IP, IS, or OA
*** 2) These variables are not missing: PatID, DX, EncType, and ADate
*** 3) EncType is recoded as follows and renamed to Setting:
***    OA ==> AV
***    IS ==> IP
*** 4) Create new character variable Period, which is the year value of ADate
*** 5) Dx has any periods removed and is renamed to Code;

%TableExtract(
  MSCDMTable=indata.&DIATABLE.,
  TableInVars=PatID DX_CodeType DX ADate EncType,
  EventDate=ADate,
  FilterCode=(DX_CodeType="09"
      and EncType in ("AV" "ED" "IP" "IS" "OA")
      and CMiss(PatID, DX, DX_CodeType, EncType)=0
      and NMiss(ADate)=0
      and &DP_MinDate. <= ADate <= &DP_MaxDate.)
  ,
  TransformCode=%nrstr(
    Period=put(_Year,4.);
    Setting=ifc(EncType="OA","AV",ifc(EncType="IS","IP",EncType));
    Code=compress(Dx,".");
    ),
  DemHashTable=DPTemp.Patkeyscovkey,
  HashVarKeys=PatID,
  HashVarsRead=PatKey Birth_Date Sex,
  CovKeyVars=CovKeyDrugAndMed,
  OutName=DPtemp.Dx,
  OutType=V,
  TableOutVars=PatKey Code ADate Setting Period AgeEventGroupKey AgeTimePeriodGroupKey Sex,
  Lengths=Code $5 Setting $2,           /* (OPTIONAL) DATA STEP variables and lengths that require adjustment            */
  SplitTime=N,
  ReplaceVarPairs=%str(PatID|PatKey Dx|Code)
  );

 * End of dx_etl.sas;
